# Releases

## 0.1.1
*September 24 2024*

* Relax Python dependency to fix issue with conda Windows build
* Make tests lighter weight and provide more coverage
* Small bug fix to regularly spaced Simpson's method

## 0.1.0
*September 9 2024*

Python coherent structure package which implements the following features:

**Diagnostics:**

* **FTLE** -- finite time Lyapunov exponent
* **iLE** -- instantaneous Lyapunov exponent
* **LAVD** -- Lagrangian averaged vorticity deviation
* **IVD** -- instantaneous vorticity deviation

**Feature extraction**:

* **LCS** -- hyperbolic and elliptic Lagrangian coherent structures
* **OECS** -- hyperbolic and elliptic objective Eulerian coherent structures
* **Ridge extraction** -- FTLE and iLE ridge extraction

Some demonstrations are available in the examples folder.
